@@ -4,6 +4,9 @@
 #include <QtCore>
 #include <QContact>
 #include <QContactId>
+#include <QContactManager>
+
+using namespace QtMobility;
 
 class k9call;
 
@@ -22,6 +25,9 @@ signals:
 public slots:
     void syncContacts();
     void syncContactIds();
+
+private:
+	QtMobility::QContactManager m_Manager;
 };
 
 #endif // CONTACTSTHREADWORKER_H
