@@ -23,7 +23,7 @@ using namespace QtMobility;
 
 static const char* KEYPAD_IDX_PROPERTY = "keypadidx";
 
-static const unsigned int CACHE_VERSION = 13;
+static const unsigned int CACHE_VERSION = 14;
 
 static const int MAX_NAME_SIZE = 30 /*pt*/;
 
@@ -349,13 +349,15 @@ void k9call::call()
 {
 	// Update accelerator
 	QString search = m_SearchString;
-	while(!search.isEmpty()) {
+	while(m_ActiveListItr != m_ActiveList.constEnd() && !search.isEmpty()) {
 		QPair<QContactLocalId, QContactLocalId>& accel = m_Accel[search];
 		QContactLocalId id = *m_ActiveListItr;
 		if(accel.first == 0 || accel.second == id)
 			accel.first = id;
-		else
+		else {
 			accel.second = id;
+      break;
+    }
 		search.truncate(search.length()-1);
 	}
 
